@@ -25,14 +25,12 @@ KgpgDetailedInfo::KgpgDetailedInfo(QWidget *parent, const QString &boxLabel, con
 	: KDialog(parent)
 {
 	if (!caption.isEmpty())
-		setCaption(caption);
+		setWindowTitle(caption);
 	else
-		setCaption(i18n("Info"));
+		setWindowTitle(i18n("Info"));
 	setButtons(Details | Ok);
 	setDefaultButton(Ok);
 	setModal(true);
 	KMessageBox::createKMessageBox(this, QMessageBox::Information, // krazy:exclude=qtclasses
 				   boxLabel, keysList, QString(), Q_NULLPTR, 0, errormessage);
 }
-
-#include "detailedconsole.moc"
