@@ -27,9 +27,11 @@
 #include <KConfigGroup>
 #include <KLocale>
 #include <KMessageBox>
+#include <QDrag>
 #include <QDragMoveEvent>
 #include <QDropEvent>
 #include <QHeaderView>
+#include <QMimeData>
 
 KeyTreeView::KeyTreeView(QWidget *parent, KeyListProxyModel *model)
 	: QTreeView(parent), m_proxy(model)
@@ -227,5 +229,3 @@ KeyTreeView::isEditing() const
 {
 	return (state() == EditingState);
 }
-
-#include "keytreeview.moc"
