@@ -29,15 +29,13 @@
 #include <KMessageBox>
 #include <KWindowSystem>
 #include <KMimeType>
-#include <QApplication>
-#include <QtDBus/QtDBus>
 
 using namespace KgpgCore;
 
 KGpgApp::KGpgApp()
              : KUniqueApplication(),
 	     running(false),
-	     w(NULL),
+	     w(Q_NULLPTR),
 	     s_keyManager(0)
 {
 }
@@ -189,5 +187,3 @@ int KGpgApp::newInstance()
 
 	return 0;
 }
-
-#include "kgpg.moc"
