@@ -20,14 +20,10 @@
 #include "kgpgsettings.h"
 
 #include <KComboBox>
-#include <KDebug>
 #include <KHBox>
-#include <KLineEdit>
 #include <KLocale>
 #include <KMessageBox>
-#include <QGroupBox>
 #include <QIntValidator>
-#include <QLabel>
 #include <QStringList>
 #include <QVBoxLayout>
 #include <QWhatsThis>
@@ -253,5 +249,3 @@ QString KgpgKeyGenerate::comment() const
         return QString();
     return m_comment->text();
 }
-
-#include "kgpgkeygenerate.moc"
