@@ -16,7 +16,6 @@
 #include "gpgproc.h"
 
 #include <KLocale>
-#include <KMessageBox>
 #include <kpimutils/email.h>
 #include <QApplication>
 
@@ -262,5 +261,3 @@ KGpgGenerateKey::gpgErrorMessage() const
 {
 	return m_errorOutput;
 }
-
-#include "kgpggeneratekey.moc"
